@@ -1,3 +1,4 @@
+//@line 40 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailWindow.js"
 
 //This file stores variables common to mail windows
 var messengerContractID        = "@mozilla.org/messenger;1";
@@ -163,7 +164,7 @@ function CreateMailWindowGlobals()
 
   //Create datasources
   accountManagerDataSource = Components.classes[accountManagerDSContractID].createInstance();
-  folderDataSource         = Components.classes[folderDSContractID].createInstance();
+  folderDataSource         = Components.classes[folderDSContractID].getService();
 
   accountCentralBox = document.getElementById("accountCentralBox");
   gSearchBox = document.getElementById("searchBox");
@@ -261,7 +262,7 @@ nsMsgStatusFeedback.prototype =
     {
       if (status.length > 0)
       {
-        myDefaultStatus = status;
+        this.myDefaultStatus = status;
         this.statusTextFld.label = status;
       }
     },
@@ -284,9 +285,9 @@ nsMsgStatusFeedback.prototype =
     {
       this.ensureStatusFields();
       if ( !statusText.length )
-        statusText = myDefaultStatus;
+        statusText = this.myDefaultStatus;
       else
-        myDefaultStatus = "";
+        this.myDefaultStatus = "";
       this.statusTextFld.label = statusText;
   },
   _startMeteors : function()
@@ -447,35 +448,55 @@ function StopUrls()
   msgWindow.StopUrls();
 }
 
-function loadStartPage() {
-    try {
-        // collapse the junk bar
-        SetUpJunkBar(null);
-        SetUpRemoteContentBar(null);
+function loadStartPage() 
+{
+  try 
+  {
+    gMessageNotificationBar.clearMsgNotifications();
+    
+    var startpageenabled = pref.getBoolPref("mailnews.start_page.enabled");
+    if (startpageenabled) 
+    {
+      
+      var startpage = pref.getComplexValue("mailnews.start_page.url", Components.interfaces.nsIPrefLocalizedString).data;
 
-        var startpageenabled = pref.getBoolPref("mailnews.start_page.enabled");
+      // Some users have our old default start page
+      // showing up as a user pref instead of a default pref. If this is the case, clear the user pref by hand 
+      // and re-read it again so we get the correct default start page.
+      if (startpage == "chrome://messenger/locale/start.html")
+      {
+        pref.clearUserPref("mailnews.start_page.url");
+        startpage = pref.getComplexValue("mailnews.start_page.url", Components.interfaces.nsIPrefLocalizedString).data;
+      }
 
-        if (startpageenabled) {
-            var startpage = pref.getComplexValue("mailnews.start_page.url",
-                                                 Components.interfaces.nsIPrefLocalizedString).data;
-            if (startpage != "") {
-                GetMessagePaneFrame().location = startpage;
-                //dump("start message pane with: " + startpage + "\n");
-                ClearMessageSelection();
-            }
-        }
-    }
-    catch (ex) {
-        dump("Error loading start page.\n");
-        return;
+      if (startpage != "") 
+      {
+        GetMessagePaneFrame().location.href = startpage;
+        //dump("start message pane with: " + startpage + "\n");
+        ClearMessageSelection();
+      }
     }
+  }
+  catch (ex) 
+  {
+    dump("Error loading start page.\n");
+    return;
+  }
 }
 
-// Display AccountCentral page when users clicks on the Account Folder.
-// When AccountCentral page need to be shown, we need to hide
-// the box containing threadPane, splitter and messagePane.
-// Load iframe in the AccountCentral box with corresponding page
 function ShowAccountCentral()
+{
+  if (document.getElementById("displayDeck").selectedPanel == accountCentralBox)
+    ShowingAccountCentral(); // force us to reload account central because the user has switched accounts
+  else
+    document.getElementById("displayDeck").selectedPanel = accountCentralBox;
+}
+
+// When AccountCentral is shown via the displayDeck, we need to switch the
+// displayDeck to show the accountCentralBox, collapse all the other
+// UI elements that aren't meaningful for AccountCentral, and finally
+// load the iframe in the AccountCentral box with corresponding page.
+function ShowingAccountCentral()
 {
     try
     {
@@ -484,11 +505,8 @@ function ShowAccountCentral()
         GetMessagePane().collapsed = true;
         document.getElementById("threadpane-splitter").collapsed = true;
         gSearchBox.collapsed = true;
-        
-        GetThreadTree().collapsed = true;
-        document.getElementById("accountCentralBox").collapsed = false;
 
-        window.frames["accountCentralPane"].location = acctCentralPage;
+        window.frames["accountCentralPane"].location.href = acctCentralPage;
         
         if (!IsFolderPaneCollapsed())
             GetFolderTree().focus();        
@@ -498,32 +516,57 @@ function ShowAccountCentral()
     catch (ex)
     {
         dump("Error loading AccountCentral page -> " + ex + "\n");
-        return;
     }
 }
 
-// Display thread and message panes with splitter when user tries
-// to read messages by clicking on msgfolders. Hide AccountCentral
-// box and display message box.
-function HideAccountCentral()
+function HidingAccountCentral()
 {
     try
     {
-        window.frames["accountCentralPane"].location = "about:blank";
-        document.getElementById("accountCentralBox").collapsed = true;
-        GetThreadTree().collapsed = false;
-        gSearchBox.collapsed = false;
-        
-        var threadPaneSplitter = document.getElementById("threadpane-splitter");
-        threadPaneSplitter.collapsed = false;
-        GetMessagePane().collapsed = threadPaneSplitter.getAttribute("state") == "collapsed";
-        gAccountCentralLoaded = false;
+        window.frames["accountCentralPane"].location.href = "about:blank";
     }
     catch (ex)
     {
         dump("Error hiding AccountCentral page -> " + ex + "\n");
-        return;
     }
+    gAccountCentralLoaded = false;
+}
+
+function ShowThreadPane()
+{
+    document.getElementById("displayDeck").selectedPanel = 
+        document.getElementById("threadPaneBox");
+}
+
+function ShowingThreadPane()
+{
+    gSearchBox.collapsed = false;
+    var threadPaneSplitter = document.getElementById("threadpane-splitter");
+    threadPaneSplitter.collapsed = false;
+    GetMessagePane().collapsed =
+        (threadPaneSplitter.getAttribute("state") == "collapsed");
+}
+
+function HidingThreadPane()
+{
+    ClearThreadPane();
+}
+
+function ObserveDisplayDeckChange(event)
+{
+    var deck = document.getElementById("displayDeck");
+    var nowSelected = null;
+    try { nowSelected = deck.selectedPanel.id; } catch (ex) { }
+
+    if (nowSelected == "threadPaneBox")
+        ShowingThreadPane();
+    else
+        HidingThreadPane();
+    
+    if (nowSelected == "accountCentralBox")
+        ShowingAccountCentral();
+    else
+        HidingAccountCentral();
 }
 
 // Given the server, open the twisty and the set the selection
@@ -532,7 +575,7 @@ function HideAccountCentral()
 function OpenInboxForServer(server)
 {
     try {
-        HideAccountCentral();
+        ShowThreadPane();
         var inboxFolder = GetInboxFolder(server);
         SelectFolder(inboxFolder.URI);
 
